Public methods
Method new()
Create a FilterJMI object.
Usage
FilterJMI$new(
id = "jmi",
task_type = "classif",
param_set = ParamSet$new(list(ParamInt$new("threads", lower = 0L, default = 0L))),
packages = "praznik",
feature_types = c("integer", "numeric", "factor", "ordered")
)Arguments
id(character(1))
Identifier for the filter.
task_type(character())
Types of the task the filter can operator on. E.g., "classif" or
"regr".
param_set(paradox::ParamSet)
Set of hyperparameters.
packages(character())
Set of required packages.
Note that these packages will be loaded via requireNamespace(), and
are not attached.
feature_types(character())
Feature types the filter operates on.
Must be a subset of
mlr_reflections$task_feature_types.
Method clone()
The objects of this class are cloneable with this method.
Usage
FilterJMI$clone(deep = FALSE)
Arguments
deepWhether to make a deep clone.